/*
** Module   : FontMetricsHelper.java
** Abstract : provides an API for font metrics
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 GES 20150427 Created initial version.
*/

package com.goldencode.p2j.ui.client;

/**
 * Provides an API for font metrics.
 */
public interface FontMetricsHelper
{
   /**
    * Report the advance width of the given character.  Advance width measures the length of the 
    * character's baseline.
    *
    * @param    ch
    *           The character to size.
    *
    * @return   The width.
    */
   public int charWidth(char ch);
   
   /**
    * Report the advance widths of the first 256 characters in the font.  Advance width measures 
    * the length of the character's baseline.
    *
    * @return   The array of widths.
    */
   public int[] getWidths();
   
   /**
    * Report the advance width of the given text.  Advance width measures the length of the 
    * text's baseline.  This may not be the same as the sum of the advance widths for each
    * character in the text.
    *
    * @param    text
    *           The string to size.
    *
    * @return   The total width.
    */
   public int stringWidth(String text);
   
   /**
    * Report the height of a line of text.  This measures the length between the baseline of
    * two sequential lines of text.
    *
    * @return   The line height.
    */
   public int getHeight();
}
