/*
** Module   : ImageWrapper.java
** Abstract : contains the state for a native image
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 GES 20150420 First version.
*/

package com.goldencode.p2j.ui.client.gui.driver;

/**
 * Contains the state for a native image which can be accessed in a general purpose manner.
 */
public class ImageWrapper<I>
{
   /** Contained native image. */
   private I image = null;
   
   /** Image height in pixels. */
   private int height = 0;
   
   /** Image width in pixels. */
   private int width = 0;
   
   /**
    * Construct an instance.
    *
    * @param    image
    *           The contained native image.
    * @param    height
    *           Image height in pixels.
    * @param    width
    *           Image width in pixels.
    */
   public ImageWrapper(I image, int height, int width)
   {
      this.image  = image;
      this.height = height;
      this.width  = width;
   }
   
   /**
    * Obtain the contained native image instance.
    *
    * @return   The contained image.
    */
   public I getImage()
   {
      return image;
   }
   
   /**
    * Obtain the height of the image in pixels.
    *
    * @return   The height in pixels.
    */
   public int getHeight()
   {
      return height;
   }
   
   /**
    * Obtain the width of the image in pixels.
    *
    * @return   The width in pixels.
    */
   public int getWidth()
   {
      return width;
   }
}
