/*
** Module   : AbstractHandlerCommons.java
** Abstract : an abstract class used to load modules
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- -------------------------------Description-----------------------------------
** 001 MAG 20140708 First version. Code moved from DojoToolkitHandler.
** 002 GES 20150308 Moved to a more generic package location.
*/

package com.goldencode.p2j.web;

import java.io.*;
import java.net.*;

import javax.servlet.http.*;

import org.eclipse.jetty.server.handler.*;

/**
 * This abstract class contains the common part of handlers which load javascript modules 
 * or other classpath resources like Dojo toolkit.
 */
public abstract class AbstractHandlerCommons
extends AbstractHandler
{
   /** Buffer size. */
   private static final int BUFFER_SIZE = 4096;
   
   /** Data buffer. */
   private byte[] buffer = new byte[BUFFER_SIZE];

   /**
    * Build HTTP response.
    * 
    * @param   response 
    *          The object or a wrapper of the response. 
    * @param   conn
    *          Module resource.
    * @param   module
    *          Module name.
    *          
    * @throws  IOException
    *          On I/O errors.
    */
   protected void sendResponse(HttpServletResponse response, URLConnection conn, String module) 
   throws IOException
   {
      // set response headers and status
      response.setStatus(HttpServletResponse.SC_OK);
      response.setContentType(detectContentType(module));
      response.setContentLength(conn.getContentLength());
      
      // build response body
      InputStream is = conn.getInputStream();
      OutputStream os = response.getOutputStream();
      
      int bytesRead = is.read(buffer);            
      while (bytesRead > 0)
      {
         os.write(buffer, 0, bytesRead);
         bytesRead = is.read(buffer);            
      }

      // cleanup
      os.flush();
      is.close();               
   }

   /**
    * Detect content type based on module file extension.
    * 
    * @param   module
    *          Module name.
    *          
    * @return  Content type (MIME).
    */
   protected String detectContentType(String module)
   {
      String contentType = "application/octet-stream";

      if (module.endsWith(".js"))
      {
         contentType = "application/javascript";
      }
      else if (module.endsWith(".css"))
      {
         contentType = "text/css";
      }
      else if (module.endsWith(".gif"))
      {
         contentType = "image/gif";
      }
      else if (module.endsWith(".png"))
      {
         contentType = "image/png";
      }
      else if (module.endsWith(".jpg") || module.endsWith(".jpeg"))
      {
         contentType = "image/jpeg";
      }
      else if (module.endsWith(".html") || module.endsWith(".htm"))
      {
         contentType = "txt/html";         
      }      
      
      return contentType;
   }
}
